pub struct ChannelCodec {
link_version: u16,
}Expand description
This object can be used to encode and decode channel cells.
NOTE: only link protocol versions 4 and higher are supported. VERSIONS cells are not supported via the encoder/decoder, since VERSIONS cells always use a two-byte circuit-ID for backwards compatibility with protocol versions < 4.
The implemented format is one of the following:
Variable-length cells:
u32 circid;
u8 command;
u16 len;
u8 body[len];Fixed-width cells:
u32 circid;
u8 command;
u8 body[509];Fields
link_version: u16The link protocol version being used for this channel.
(We don’t currently support any versions of the link protocol where this version matters, but for protocol versions below 4, it would have affected the length of the circuit ID.)
Implementations
Sourceimpl ChannelCodec
impl ChannelCodec
Sourcepub fn new(link_version: u16) -> Self
pub fn new(link_version: u16) -> Self
Create a new ChannelCodec with a given link protocol version
Sourcepub fn link_version(&self) -> u16
pub fn link_version(&self) -> u16
Return the link protocol version of this codec.
Sourcepub fn write_cell<M: ChanMsg>(
&mut self,
item: ChanCell<M>,
dst: &mut BytesMut,
) -> Result<()>
pub fn write_cell<M: ChanMsg>( &mut self, item: ChanCell<M>, dst: &mut BytesMut, ) -> Result<()>
Write the given cell into the provided BytesMut object.
Sourcepub fn decode_cell<M: ChanMsg>(
&mut self,
src: &mut BytesMut,
) -> Result<Option<(ChanCell<M>, Bytes)>>
pub fn decode_cell<M: ChanMsg>( &mut self, src: &mut BytesMut, ) -> Result<Option<(ChanCell<M>, Bytes)>>
Try to decode a cell from the provided BytesMut object.
On a definite decoding error, return Err(_).
On a cell that might just be truncated, return Ok(None).
Returns both the cell and the bytes that the cell were decoded from. These bytes are intended for SLOG/CLOG calculations.