macro_rules! msg_impl_chanmsg {
($($body:ident,)*) => { ... };
}Expand description
Helper: declare a ChanMsg implementation for a message type that has a fixed command.
macro_rules! msg_impl_chanmsg {
($($body:ident,)*) => { ... };
}Helper: declare a ChanMsg implementation for a message type that has a fixed command.