#[non_exhaustive]
pub enum Error {
    BytesErr {
        err: Error,
        parsed: &'static str,
    },
    EncodeErr(EncodeError),
    Internal(Bug),
    ChanProto(String),
    BadStreamAddress,
    CantEncode(&'static str),
}
An error type for the tor-cell crate.

This type should probably be split into several. There’s more than one kind of error that can occur while doing something with tor cells.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

BytesErr

Fields

err: Error

The error that occurred.

parsed: &'static str

The thing that was being parsed.

An error that occurred in the tor_bytes crate while decoding an object.

EncodeErr(EncodeError)

We encountered an error while encoding an outgoing message.

This is likely to be a bug in somebody’s code: either the code in this crate, or in the calling code that provided an unencodable message.

Internal(Bug)

There was a programming error somewhere in the code.

ChanProto(String)

Protocol violation at the channel level

BadStreamAddress

Tried to make or use a stream to an invalid destination address.

CantEncode(&'static str)

Tried to construct a message that Tor can’t represent.