fn is_strictly_ascending(vers: &[NumberedSubver]) -> boolExpand description
Return true iff the list of protocol capabilities is strictly ascending.
fn is_strictly_ascending(vers: &[NumberedSubver]) -> boolReturn true iff the list of protocol capabilities is strictly ascending.