ExtGroup

Trait ExtGroup 

pub(super) trait ExtGroup: Readable + Writeable {
    type Id: From<u8> + Into<u8> + Eq + PartialEq + Ord + Copy;

    // Required method
    fn type_id(&self) -> Self::Id;
}
A kind of extension that can be used with some kind of relay message.

Each extendible message will likely define its own enum, implementing this trait, representing the possible extensions.

Required Associated Types

type Id: From<u8> + Into<u8> + Eq + PartialEq + Ord + Copy

An identifier kind used with this sort of extension

Required Methods

fn type_id(&self) -> Self::Id

The field-type id for this particular extension.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors