DosParams

Struct DosParams 

pub struct DosParams {
    rate_per_sec: Option<BoundedInt32<0, { i32::MAX }>>,
    burst_per_sec: Option<BoundedInt32<0, { i32::MAX }>>,
}
Extension to tell the introduction point to rate-limit.

When we sent this extension, it tells the introduction point to rate-limit the INTRODUCE2 messages it sends us to the rates shown here.

When this extension is not sent, the introduction point imposes a rate-limit depending on parameters in the latest consensus.

This extension requires protover HSIntro=5.

See https://spec.torproject.org/rend-spec/introduction-protocol.html#EST_INTRO_DOS_EXT.

Fields

rate_per_sec: Option<BoundedInt32<0, { i32::MAX }>>

An optional parameter indicates the rate per second of INTRODUCE2 cell relayed to the service.

Min: 0, Max: 2147483647

burst_per_sec: Option<BoundedInt32<0, { i32::MAX }>>

An optional parameter indicates the burst per second of INTRODUCE2 cell relayed to the service

Min: 0, Max: 2147483647

Implementations

Source

impl DosParams

pub fn new( rate_per_sec: Option<i32>, burst_per_sec: Option<i32>, ) -> Result<Self>

Create a new establish intro DoS extension.