pub struct EstablishIntro {
body: EstablishIntroDetails,
handshake_auth: CtByteArray<HS_MAC_LEN>,
mac_plaintext: Vec<u8>,
sig: Box<ValidatableEd25519Signature>,
}Expand description
A hidden services establishes a new introduction point, by sending an EstablishIntro message.
This may represent either an outbound body that we’re sending, or a decoded body that we’re receiving.
Usage
This type is a good choice for handling an incoming EstablishIntro message on a Relay, but not for generating an outgoing EstablishIntro message.
Onion services should not construct this message object; instead, they
should construct an EstablishIntroDetails, and then call its
sign_and_encode method.
Fields
body: EstablishIntroDetailsThe underlying body of this, wrapped in authentication.
handshake_auth: CtByteArray<HS_MAC_LEN>The MAC of all earlier fields in the cell, using a key derived from the handshake between the onion service and the introduction point.
This MAC binds the EstablishIntro message to a single circuit, and keeps it from being replayed.
mac_plaintext: Vec<u8>A textual record of all the fields in the message that are covered by the MAC.
sig: Box<ValidatableEd25519Signature>A signature using auth_key of all contents of the message.
This signature proves possession of auth_key and thereby ensures that
the request really comes from that key’s holder.
(This field is boxed to manage variant size.)
Implementations
Sourceimpl EstablishIntro
impl EstablishIntro
Sourcepub fn from_parts_for_test(
body: EstablishIntroDetails,
mac: CtByteArray<HS_MAC_LEN>,
signature: Signature,
) -> Self
pub fn from_parts_for_test( body: EstablishIntroDetails, mac: CtByteArray<HS_MAC_LEN>, signature: Signature, ) -> Self
Sourcepub fn check_and_unwrap<'a>(
self,
mac_key: impl Into<HsMacKey<'a>>,
) -> Result<EstablishIntroDetails, EstablishIntroSigError>
pub fn check_and_unwrap<'a>( self, mac_key: impl Into<HsMacKey<'a>>, ) -> Result<EstablishIntroDetails, EstablishIntroSigError>
Check whether this EstablishIntro message is well-signed (with its included key), and well authenticated with the provided MAC key.
On success, return the EstablishIntroDetails describing how to function
as an introduction point for this service. On failure, return an error.
Sourcepub fn dangerously_unwrap(self) -> EstablishIntroDetails
pub fn dangerously_unwrap(self) -> EstablishIntroDetails
Consume this EstablishIntro message and return its body.
This is a “dangerous” function because it does not check correctness for the signature or the MAC.