pub struct EstablishIntroDetails {
auth_key: Ed25519Identity,
extensions: ExtList<EstablishIntroExt>,
}Expand description
The body of an EstablishIntro message, after the signature and MAC are verified.
This tells the introduction point which key it should act as an introduction for, and how.
Fields
auth_key: Ed25519IdentityThe public introduction point auth key.
extensions: ExtList<EstablishIntroExt>A list of extensions on this cell.
Implementations
Sourceimpl EstablishIntroDetails
impl EstablishIntroDetails
Sourcepub fn new(auth_key: Ed25519Identity) -> Self
pub fn new(auth_key: Ed25519Identity) -> Self
All arguments constructor
Sourcepub fn set_extension_dos(&mut self, extension_dos: DosParams)
pub fn set_extension_dos(&mut self, extension_dos: DosParams)
Set EST_INTRO_DOS_EXT with given extension_dos.
Sourcepub fn set_extension_other(&mut self, other: UnrecognizedExt<EstIntroExtType>)
pub fn set_extension_other(&mut self, other: UnrecognizedExt<EstIntroExtType>)
Add an extension of some other type.
Sourcepub fn sign_and_encode<'a>(
self,
keypair: &Keypair,
mac_key: impl Into<HsMacKey<'a>>,
) -> Result<Vec<u8>>
pub fn sign_and_encode<'a>( self, keypair: &Keypair, mac_key: impl Into<HsMacKey<'a>>, ) -> Result<Vec<u8>>
Sign and authenticate this body using a provided Ed25519 keypair and MAC key.
The MAC key is derived from the circuit handshake between the onion service and the introduction point. The Ed25519 keypair must match the one given as the auth_key for this body.