pub struct IntroduceHandshakePayload {
cookie: RendCookie,
extensions: ExtList<CircRequestExt>,
onion_key: OnionKey,
link_specifiers: Vec<EncodedLinkSpec>,
}Expand description
The plaintext of the encrypted portion of an INTRODUCE{1,2} message.
This is not a RelayMsg itself; it is instead used as the payload for an
hs-ntor handshake, which is passed to the onion service in Introduce[12]
message.
This payload is sent from a client to the onion service to tell it how to reach the client’s chosen rendezvous point.
This corresponds to the “decrypted payload” in section 3.3 of rend-spec-v3.txt, excluding the PAD field.
The user of this type is expected to discard, or generate, appropriate padding, as required.
Fields
The rendezvous cookie to use at the rendezvous point.
(RENDEZVOUS_COOKIE in the spec.)
extensions: ExtList<CircRequestExt>A list of extensions to this payload.
(N_EXTENSIONS, EXT_FIELD_TYPE, EXT_FIELD_LEN, and EXT_FIELD in
the spec.)
onion_key: OnionKeyThe onion key to use when extending a circuit to the rendezvous point.
(ONION_KEY_TYPE, ONION_KEY_LEN, and ONION_KEY in the spec. This
represents KP_ntor for the rendezvous point.)
link_specifiers: Vec<EncodedLinkSpec>A list of link specifiers to identify the rendezvous point.
(NSPEC, LSTYPE, LSLEN, and LSPEC in the spec.)
Implementations
Sourceimpl IntroduceHandshakePayload
impl IntroduceHandshakePayload
Sourcepub fn new(
cookie: RendCookie,
onion_key: OnionKey,
link_specifiers: Vec<EncodedLinkSpec>,
proof_of_work: Option<ProofOfWork>,
) -> Self
pub fn new( cookie: RendCookie, onion_key: OnionKey, link_specifiers: Vec<EncodedLinkSpec>, proof_of_work: Option<ProofOfWork>, ) -> Self
Construct a new IntroduceHandshakePayload
Return the rendezvous cookie specified in this handshake payload.
Sourcepub fn onion_key(&self) -> &OnionKey
pub fn onion_key(&self) -> &OnionKey
Return the provided onion key for the specified rendezvous point
Sourcepub fn link_specifiers(&self) -> &[EncodedLinkSpec]
pub fn link_specifiers(&self) -> &[EncodedLinkSpec]
Return the provided link specifiers for the specified rendezvous point.
Sourcepub fn proof_of_work_extension(&self) -> Option<&ProofOfWork>
pub fn proof_of_work_extension(&self) -> Option<&ProofOfWork>
Return the proof-of-work extension for the specified rendezvous point.