#[non_exhaustive]pub enum ProofOfWork {
Unrecognized(UnrecognizedProofOfWork),
V1(ProofOfWorkV1),
}Expand description
Extension to provide a proof of work for denial of service mitigation
Documented at https://spec.torproject.org/rend-spec/introduction-protocol.html#INTRO1_POW_EXT
The extension has a variable format depending on the specific scheme that was chosen.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unrecognized(UnrecognizedProofOfWork)
A potential solution with unrecognized scheme
V1(ProofOfWorkV1)
A potential solution using the v1 scheme