pub struct ProofOfWorkV1 {
nonce: Nonce,
effort: Effort,
seed_head: SeedHead,
solution: SolutionByteArray,
}Expand description
Proof of work using the v1 scheme
Specified as part of https://spec.torproject.org/rend-spec/introduction-protocol.html#INTRO1_POW_EXT
Fields
nonce: NonceNonce value chosen by the client
effort: EffortEffort chosen by the client
seed_head: SeedHeadHeader with which to identify the applicable service-provided seed
solution: SolutionByteArrayProposed solution proof, not validated
This byte array still needs to be validated first as a well-formed Equix solution, and then as a proof for a particular puzzle.
Implementations
Sourceimpl ProofOfWorkV1
impl ProofOfWorkV1
pub const fn new( nonce: Nonce, effort: Effort, seed_head: SeedHead, solution: SolutionByteArray, ) -> ProofOfWorkV1
Sourceimpl ProofOfWorkV1
impl ProofOfWorkV1
Sourcepub fn nonce(&self) -> &Nonce
pub fn nonce(&self) -> &Nonce
Method borrowing ProofOfWorkV1::nonce field.
Nonce value chosen by the client
Sourcepub fn effort(&self) -> Effort
pub fn effort(&self) -> Effort
Method returning copy of ProofOfWorkV1::effort field.
Effort chosen by the client
Sourcepub fn seed_head(&self) -> SeedHead
pub fn seed_head(&self) -> SeedHead
Method returning copy of ProofOfWorkV1::seed_head field.
Header with which to identify the applicable service-provided seed
Sourcepub fn solution(&self) -> &SolutionByteArray
pub fn solution(&self) -> &SolutionByteArray
Method borrowing ProofOfWorkV1::solution field.
Proposed solution proof, not validated
Sourceimpl ProofOfWorkV1
impl ProofOfWorkV1
Sourcepub(super) fn try_take_body_from(
scheme: u8,
b: &mut Reader<'_>,
) -> Result<Option<Self>>
pub(super) fn try_take_body_from( scheme: u8, b: &mut Reader<'_>, ) -> Result<Option<Self>>
Construct by reading the scheme-specific data, if the scheme ID is correct for ProofOfWorkV1
Sourcepub(super) fn write_onto<B: Writer + ?Sized>(
&self,
b: &mut B,
) -> EncodeResult<()>
pub(super) fn write_onto<B: Writer + ?Sized>( &self, b: &mut B, ) -> EncodeResult<()>
Write the scheme and scheme-specific portion the v1 Proof Of Work