pub struct IntroduceAckStatus(u16);Expand description
A status code returned in response to an INTRODUCE1 message.
Tuple Fields
0: u16Implementations
Sourceimpl IntroduceAckStatus
impl IntroduceAckStatus
Sourcepub const SUCCESS: IntroduceAckStatus
pub const SUCCESS: IntroduceAckStatus
The message was relayed successfully.
Sourcepub const NOT_RECOGNIZED: IntroduceAckStatus
pub const NOT_RECOGNIZED: IntroduceAckStatus
The introduction point does not have a live circuit from the identified service.
Sourcepub const BAD_MESSAGE_FORMAT: IntroduceAckStatus
pub const BAD_MESSAGE_FORMAT: IntroduceAckStatus
There was a failure while parsing the INTRODUCE1 message.
Sourcepub const CANT_RELAY: IntroduceAckStatus
pub const CANT_RELAY: IntroduceAckStatus
The introduction point was unable to deliver the message to the service.
fn to_str(self) -> Option<&'static str>
Sourcepub fn is_recognized(self) -> bool
pub fn is_recognized(self) -> bool
Return true if this value is one that we recognize.