pub struct Rendezvous1 {
cookie: RendCookie,
handshake_info: Vec<u8>,
}Expand description
A message sent from an onion service to a rendezvous point, telling it to make a connection to the client.
Fields
The cookie originally sent by the client in its ESTABLISH_REND message.
handshake_info: Vec<u8>The message to send the client.
Implementations
Sourceimpl Rendezvous1
impl Rendezvous1