macro_rules! empty_body {
{
$(#[$meta:meta])*
pub struct $name:ident {}
} => { ... };
}Expand description
Declare a message type for a message with an empty body.
macro_rules! empty_body {
{
$(#[$meta:meta])*
pub struct $name:ident {}
} => { ... };
}Declare a message type for a message with an empty body.