macro_rules! msg_impl_relaymsg {
($($body:ident),* $(,)?) => { ... };
}Expand description
Helper: declare a RelayMsg implementation for a message type that has a fixed command.
macro_rules! msg_impl_relaymsg {
($($body:ident),* $(,)?) => { ... };
}Helper: declare a RelayMsg implementation for a message type that has a fixed command.