pub struct Extend2 { /* private fields */ }Expand description
An Extend2 message tells the last relay in a circuit to extend to a new hop.
When a relay (call it R) receives an Extend2 message, it tries to find (or make) a channel to the other relay (R’) described in the list of link specifiers. (A link specifier can be an IP addresses or a cryptographic identity). Once R has such a channel, the it packages the client’s handshake data as a new Create2 message R’. If R’ replies with a Created2 (success) message, R packages that message’s contents in an Extended message. Unlike Extend messages, Extend2 messages can encode any handshake type, and can describe relays in ways other than IPv4 addresses and RSA identities.
Implementations
Sourceimpl Extend2
impl Extend2
Sourcepub fn new(
linkspec: Vec<EncodedLinkSpec>,
handshake_type: HandshakeType,
handshake: Vec<u8>,
) -> Self
pub fn new( linkspec: Vec<EncodedLinkSpec>, handshake_type: HandshakeType, handshake: Vec<u8>, ) -> Self
Create a new Extend2 cell.
Sourcepub fn handshake_type(&self) -> HandshakeType
pub fn handshake_type(&self) -> HandshakeType
Return the type of this handshake.
Sourcepub fn linkspecs(&self) -> &[EncodedLinkSpec]
pub fn linkspecs(&self) -> &[EncodedLinkSpec]
Return a reference to the link specifiers in this cell.