AnyRelayMsgOuter

Type Alias AnyRelayMsgOuter 

pub type AnyRelayMsgOuter = RelayMsgOuter<AnyRelayMsg>;
A decoded and parsed relay message of unrestricted type, with an accompanying optional Stream ID.

Aliased Type

pub struct AnyRelayMsgOuter {
    streamid: Option<StreamId>,
    msg: AnyRelayMsg,
}

Fields

streamid: Option<StreamId>

The stream ID for the stream that this cell corresponds to.

msg: AnyRelayMsg

The relay message for this cell.