pub struct Datagram {
body: Vec<u8>,
}Expand description
A Datagram message represents data sent along a UDP stream.
Upon receiving a Datagram message for a live stream, the client or exit sends that data onto the associated UDP connection.
These messages hold between 1 and Datagram::MAXLEN bytes of data each.
Fields
body: Vec<u8>Contents of the cell, to be sent on a specific stream
Implementations
Sourceimpl Datagram
impl Datagram
Sourcepub const MAXLEN: usize
pub const MAXLEN: usize
NOTE: Proposal 340, fragmented relay message, might change this value reality. The longest allowable body length for a single data cell.
Sourcepub fn new(inp: &[u8]) -> Result<Self>
pub fn new(inp: &[u8]) -> Result<Self>
Construct a new data cell.
Returns an error if inp is longer than Datagram::MAXLEN bytes.
Sourcefn new_unchecked(body: Vec<u8>) -> Self
fn new_unchecked(body: Vec<u8>) -> Self
Construct a new cell from a provided vector of bytes.
The vector must have fewer than Datagram::MAXLEN bytes.