RestrictedMsg

Trait RestrictedMsg 

pub trait RestrictedMsg {
    type Cmd: Copy + Clone + Debug + Display + Eq + PartialEq + 'static;

    // Required method
    fn cmds_for_logging() -> &'static [Self::Cmd];
}
Additional functionality for a restricted message set.

This is typically implemented using restricted_msg.

Required Associated Types

type Cmd: Copy + Clone + Debug + Display + Eq + PartialEq + 'static

The type of cell. Typically ChanCmd or RelayCmd.

Required Methods

fn cmds_for_logging() -> &'static [Self::Cmd]

The set of cell commands represented by this restricted message set.

This isn’t necessarily exhaustive and doesn’t always include all cells types that this message set can hold. For example AnyChanMsg also supports unrecognized cells, which aren’t represented in this list.

This is intended for debugging purposes, so that we can list what commands we are expecting in error messages.

NOTE: This list is not intended to be used for filtering cells or performing any kind of validation.

Implementers should ensure that the returned list does not contain duplicate values.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors