#[non_exhaustive]pub(crate) enum SliceWriterError {
Truncated,
}Expand description
An error that occurred while trying to unwrap a SliceWriter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Truncated
We’ve tried to write more than would fit into a fixed-size slice