pub struct ChannelCodec {
link_version: u16,
}Expand description
This object can be used to encode and decode channel cells.
NOTE: only link protocol versions 3 and higher are supported. VERSIONS cells are not supported via the encoder/decoder, since VERSIONS cells always use a two-byte circuit-ID for backwards compatibility with protocol versions < 4.
The implemented format is one of the following:
Variable-length cells (since protocol versions 2 and 3 respectively):
u32 circid;
u8 command;
u16 len;
u8 body[len];Fixed-width cells (since protocol version 1 and 4 respectively):
u32 circid;
u8 command;
u8 body[509];Fields
link_version: u16The link protocol version being used for this channel.
(We don’t currently support any versions of the link protocol where this version matters, but for protocol versions below 4, it would affect the length of the circuit ID.)
Implementations
Sourceimpl ChannelCodec
impl ChannelCodec
Sourcepub fn new(link_version: u16) -> Self
pub fn new(link_version: u16) -> Self
Create a new ChannelCodec with a given link protocol version
Sourcepub fn link_version(&self) -> u16
pub fn link_version(&self) -> u16
Return the link protocol version of this codec.