macro_rules! fixed_len_handshake {
{
$(#[$meta:meta])*
$name:ident , $cmd:ident, $len:ident
} => { ... };
}Expand description
helper – declare a fixed-width cell for handshake commands, in which a fixed number of bytes matter and the rest are ignored