pub(super) trait ExtGroup: Readable + Writeable {
type Id: From<u8> + Into<u8> + Eq + PartialEq + Ord + Copy;
// Required method
fn type_id(&self) -> Self::Id;
}Expand description
A kind of extension that can be used with some kind of relay message.
Each extendible message will likely define its own enum, implementing this trait, representing the possible extensions.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.