UnrecognizedProofOfWork

Struct UnrecognizedProofOfWork 

pub struct UnrecognizedProofOfWork {
    scheme: u8,
    data: Vec<u8>,
}
A proof of work with unknown scheme

The reader needs a way to represent future schemes when we can’t fail to parse. This is similar to super::UnrecognizedExt, but specific to an unrecognized scheme within a known type of extension.

Fields

scheme: u8

The scheme byte

Intended usage is that this won’t be any of the known ProofOfWorkType values. We don’t strictly verify this, to avoid breaking the API every time a new type is added.

data: Vec<u8>

Arbitrary contents with an unknown format

Implementations

Source

impl UnrecognizedProofOfWork

pub fn scheme(&self) -> u8

Method returning copy of UnrecognizedProofOfWork::scheme field. The scheme byte

pub fn data(&self) -> &Vec<u8>

Method borrowing UnrecognizedProofOfWork::data field. Arbitrary contents with an unknown format

Source

impl UnrecognizedProofOfWork

pub const fn new(scheme: u8, data: Vec<u8>) -> UnrecognizedProofOfWork

Source

impl UnrecognizedProofOfWork

pub(super) fn take_body_from(scheme: u8, b: &mut Reader<'_>) -> Self

Construct by taking the remaining scheme-specific unknown data

pub(super) fn write_onto<B: Writer + ?Sized>(&self, b: &mut B)

Write the unrecognized proof’s scheme and data