pub type AnyRelayMsgOuter = RelayMsgOuter<AnyRelayMsg>;Expand description
A decoded and parsed relay message of unrestricted type, with an accompanying optional Stream ID.
Aliased Type
pub struct AnyRelayMsgOuter {
streamid: Option<StreamId>,
msg: AnyRelayMsg,
}Fields
streamid: Option<StreamId>The stream ID for the stream that this cell corresponds to.
msg: AnyRelayMsgThe relay message for this cell.